@@ -157,10 +157,13 @@ class CWProxy:
         self.timeout = timeout
         self._ssl_verify = verify
         self._default_vid = "jsonexport"  # OR 'ejsonexport'?
-        self._csrf_token = None
         self._requests_session = requests.Session()
         self._base_url = urlparse.urlunparse(self.base_url + ("", None, None, None))
 
+    @property
+    def _csrf_token(self):
+        return self._requests_session.cookies.get("csrf_token")
+
     def handle_request(self, method: str, path: str, **kwargs):
         """Construct a requests.Request and send it through this proxy.
 
@@ -191,14 +194,13 @@ class CWProxy:
         return self._requests_session.request(method, url, **kwargs)
 
     def _grab_csrf_token(self):
-        response = self._requests_session.get(self._base_url, allow_redirects=False)
-        if "csrf_token" not in response.cookies:
+        self._requests_session.get(self._base_url, allow_redirects=False)
+        if self._csrf_token is None:
             raise FailedToGrabCSRFTokenError(
                 f"Couldn't grab a CSRF token on website {self._base_url}, this"
                 " CubicWeb instance is probably using an insecure version of CubicWeb,"
                 " ensure that it is running CubicWeb 3.32.9, 3.33.7 or higher."
             )
-        self._csrf_token = response.cookies["csrf_token"]
 
     def build_url(self, path: str, query=None):
         """Build the URL to query from self.base_url and the given path
