@@ -37,10 +37,12 @@ from cubicweb.devtools.httptest import CubicWebServerTC
 class CWProxyClientTC(CubicWebServerTC):
     """Basic tests for CWProxy"""
 
+    settings = {"cubicweb.bwcompat": True}
+
     def setup_database(self):
         with self.admin_access.client_cnx() as cnx:
             token = cnx.create_entity(
-                "AuthToken", id=u"testing", enabled=True, token_for_user=cnx.user.eid
+                "AuthToken", id="testing", enabled=True, token_for_user=cnx.user.eid
             )
             self.admineid = cnx.user.eid
             self.token_id = token.id
@@ -269,7 +271,7 @@ class CWProxyClientTC(CubicWebServerTC):
 
     def test_handle_request(self):
         with self.admin_access.cnx() as cnx:
-            eid = cnx.find("CWUser", login=u"admin")[0][0]
+            eid = cnx.find("CWUser", login="admin")[0][0]
         response = self.client.handle_request(
             "GET",
             "cwuser/{}".format(eid),
@@ -296,7 +298,7 @@ class CWProxyClientTC(CubicWebServerTC):
     @unittest.skip("to be completed and make pass")
     def test_get(self):
         with self.admin_access.client_cnx() as cnx:
-            eid = cnx.find("CWEType", name=u"CWUser")[0][0]
+            eid = cnx.find("CWEType", name="CWUser")[0][0]
         response = self.client.get("/cwetype/{}".format(eid))
         self.assertEqual(response.status_code, 200)
 
@@ -304,7 +306,7 @@ class CWProxyClientTC(CubicWebServerTC):
     def test_view(self):
         vid = "jsonexport"
         with self.admin_access.web_request() as req:
-            rset = req.find("CWEType", name=u"CWUser")
+            rset = req.find("CWEType", name="CWUser")
             json_view = req.view(vid, rset=rset)
         response = self.client.view(vid, eid=rset[0][0])
         self.assertEqual(response.status_code, 200)
@@ -357,13 +359,67 @@ class CWProxyClientTC(CubicWebServerTC):
         )
         self.assertEqual(self.client.count("EmailAddress", alias="CSE"), 1)
 
+    def test_update_by_eid(self):
+        self.assertFalse(self.client.find("EmailAddress", alias="juliette"))
+        result = self.client.insert(
+            "EmailAddress", alias="juliette", address="juliette@romance.org"
+        )
+        eid = result[0]
+        self.assertTrue(self.client.find("EmailAddress", alias="juliette"))
+        self.client.update_by_eid(eid, alias="romeo")
+        self.assertTrue(self.client.find("EmailAddress", alias="romeo"))
+
+    def test_update_batch_by_eid(self):
+        self.assertFalse(self.client.find("EmailAddress", alias="juliette"))
+        self.assertFalse(self.client.find("EmailAddress", alias="romeo"))
+        result = self.client.insert(
+            "EmailAddress", alias="juliette", address="juliette@romance.org"
+        )
+        juliette_eid = result[0]
+        result = self.client.insert(
+            "EmailAddress", alias="romeo", address="romeo@romance.org"
+        )
+        romeo_eid = result[0]
+        self.assertTrue(self.client.find("EmailAddress", alias="juliette"))
+        self.assertTrue(self.client.find("EmailAddress", alias="romeo"))
+        self.client.update_batch_by_eid(
+            [
+                {"eid": juliette_eid, "alias": "morte"},
+                {"eid": romeo_eid, "alias": "vivant"},
+            ]
+        )
+        self.assertTrue(
+            self.client.find(
+                "EmailAddress", alias="morte", address="juliette@romance.org"
+            )
+        )
+        self.assertTrue(
+            self.client.find(
+                "EmailAddress", alias="vivant", address="romeo@romance.org"
+            )
+        )
+
+    def test_update_by_restrictions(self):
+        self.client.insert(
+            "EmailAddress", alias="juliette", address="juliette@romance.org"
+        )
+        self.assertTrue(self.client.find("EmailAddress", alias="juliette"))
+        self.client.update_by_restrictions(
+            {"address": "juliette@romance.org"}, alias="morte"
+        )
+        self.assertTrue(
+            self.client.find(
+                "EmailAddress", alias="morte", address="juliette@romance.org"
+            )
+        )
+
     def test_delete(self):
         self.client.insert(
-            "EmailAddress", alias="juliette", address="juliette@logilab.fr"
+            "EmailAddress", alias="juliette", address="juliette@romance.org"
         )
         self.assertTrue(self.client.find("EmailAddress", alias="juliette"))
         self.client.delete(
-            "EmailAddress", alias="juliette", address="juliette@logilab.fr"
+            "EmailAddress", alias="juliette", address="juliette@romance.org"
         )
         self.assertFalse(self.client.find("EmailAddress", alias="juliette"))
 
